summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/kfilednddetailview.h
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/autotools/kfilednddetailview.h')
-rw-r--r--buildtools/autotools/kfilednddetailview.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/buildtools/autotools/kfilednddetailview.h b/buildtools/autotools/kfilednddetailview.h
index ecb232c6..0cf13f7e 100644
--- a/buildtools/autotools/kfilednddetailview.h
+++ b/buildtools/autotools/kfilednddetailview.h
@@ -20,8 +20,8 @@
//////////////////////////////////////////////////////////////////////
// Qt specific include files
-#include <qwidget.h>
-#include <qtimer.h>
+#include <tqwidget.h>
+#include <tqtimer.h>
//////////////////////////////////////////////////////////////////////
// KDE specific include files
#include <kfiledetailview.h>
@@ -42,7 +42,7 @@ class KFileDnDDetailView : public KFileDetailView
Q_OBJECT
public:
/** */
- KFileDnDDetailView( QWidget *parent = 0, const char *name = 0 );
+ KFileDnDDetailView( TQWidget *parent = 0, const char *name = 0 );
/** */
virtual ~KFileDnDDetailView();
/**
@@ -78,20 +78,20 @@ public:
return m_useAutoOpenTimer;
}
/** */
- virtual void readConfig( KConfig*, const QString& group = QString::null );
+ virtual void readConfig( KConfig*, const TQString& group = TQString::null );
/** */
- virtual void writeConfig( KConfig*, const QString& group = QString::null );
+ virtual void writeConfig( KConfig*, const TQString& group = TQString::null );
signals: // Signals
/**
* Emitted whenever an decodable item is dropped in the view.
* Note: The @ref QDropEvent contains a @ref KURLDrag object.
*/
- void dropped( QDropEvent* );
+ void dropped( TQDropEvent* );
/**
* Emitted whenever an decodable item is dropped in the view
* Note: The @ref QDropEvent contains a @ref KURLDrag object.
*/
- void dropped( KFileView*, QDropEvent* );
+ void dropped( KFileView*, TQDropEvent* );
/**
* Emitted whenever an decodable item is dropped in the view.
*@param urls contains a list of all dropped @ref KURL
@@ -104,13 +104,13 @@ protected slots: // Protected slots
void slotOpenFolder();
protected: //Protected Methods
/** */
- virtual void contentsDragEnterEvent( QDragEnterEvent *e );
+ virtual void contentsDragEnterEvent( TQDragEnterEvent *e );
/** */
- virtual void contentsDragMoveEvent( QDragMoveEvent *e );
+ virtual void contentsDragMoveEvent( TQDragMoveEvent *e );
/** */
- virtual void contentsDragLeaveEvent( QDragLeaveEvent *e );
+ virtual void contentsDragLeaveEvent( TQDragLeaveEvent *e );
/** */
- virtual void contentsDropEvent( QDropEvent* e );
+ virtual void contentsDropEvent( TQDropEvent* e );
/**
* Create dragobject encoding the current selection and starts the drag
*/
@@ -118,16 +118,16 @@ protected: //Protected Methods
/**
* @returns the dragObject
*/
- virtual QDragObject* dragObject() const;
+ virtual TQDragObject* dragObject() const;
/**
* @returns true if we can decode the drag and support the action
*/
- virtual bool acceptDrag( QDropEvent* event ) const;
+ virtual bool acceptDrag( TQDropEvent* event ) const;
protected: // Private attributes
- QTimer m_autoOpenTimer;
+ TQTimer m_autoOpenTimer;
int m_autoOpenTime;
bool m_useAutoOpenTimer;
- QListViewItem* m_dropItem;
+ TQListViewItem* m_dropItem;
KURLDrag* m_dragObject;
bool m_dndEnabled;
};
@@ -78,20 +78,20 @@ public:
/**
* Emitted whenever an decodable item is dropped in the view.
- * Note: The @ref QDropEvent contains a @ref KURLDrag object.
+ * Note: The @ref TQDropEvent contains a @ref KURLDrag object.
*/
@@ -78,20 +78,20 @@ public:
/**
* Emitted whenever an decodable item is dropped in the view
- * Note: The @ref QDropEvent contains a @ref KURLDrag object.
+ * Note: The @ref TQDropEvent contains a @ref KURLDrag object.
*/